@@ -215,7 +215,7 @@ class PredictionTest(object):
         cv_iterator=cv_method(predictors,target,**cv_kwargs)
         return cv_iterator
     
-    def add_score_to_index_metadata(self,indices,label='score',raise_on_missing_var=False):
+    def add_score_to_index_metadata(self,indices,label='score',raise_on_missing_var=False,reduce_func=np.mean):
         s=self.computed_scores
         if s is None:
             raise(ValueError('No scores computed.'))
@@ -223,7 +223,7 @@ class PredictionTest(object):
             
             score=s[var].values
             try:
-                indices[var].attrs[label]=score
+                indices[var].attrs[label]=reduce_func(score)
             except:
                 if raise_on_missing_var:
                     raise(ValueError(f'Key {var} present in self.computed_scores but not in indices.'))
